@@ -340,12 +340,12 @@ void Uic::createFormImpl( const TQDomElement &e )
 			images += img;
 			out << indent << img << "_data = \\" << endl;
 			++indent;
-			out << indent << "\"";
+			out << indent << "b\"";
 			int a ;
 			for ( a = 0; a < (int) (data.length()/2)-1; a++ ) {
 			    out << "\\x" << TQString(data[2*a]) << TQString(data[2*a+1]);
 			    if ( a % 12 == 11 )
-				out << "\" \\" << endl << indent << "\"";
+				out << "\" \\" << endl << indent << "b\"";
 			}
 			out << "\\x" << TQString(data[2*a]) << TQString(data[2*a+1]) << "\"" << endl;
 			--indent;
@@ -391,7 +391,7 @@ void Uic::createFormImpl( const TQDomElement &e )
 	TQStringList::Iterator it;
 	for ( it = images.begin(); it != images.end(); ++it ) {
 	    out << indent << "self." << (*it) << " = TQPixmap()" << endl;
-	    out << indent << "self." << (*it) << ".loadFromData(" << (*it) << "_data,\"PNG\")" << endl;
+	    out << indent << "self." << (*it) << ".loadFromData(" << (*it) << "_data,b\"PNG\")" << endl;
 	}
     }
     // create pixmaps for all images
