@@ -387,9 +387,9 @@ void Uic::createActionImpl( const TQDomElement &n, const TQString &parent )
     for ( TQDomElement ae = n; !ae.isNull(); ae = ae.nextSibling().toElement() ) {
 	TQString objName = registerObject( getObjectName( ae ) );
 	if ( ae.tagName() == "action" )
-	    out << indent << "self." << objName << " = TQAction(" << parent << ",\"" << objName << "\")" << endl;
+	    out << indent << "self." << objName << " = TQAction(" << parent << ",b\"" << objName << "\")" << endl;
 	else if ( ae.tagName() == "actiongroup" )
-	    out << indent << "self." << objName << " = TQActionGroup(" << parent << ",\"" << objName << "\")" << endl;
+	    out << indent << "self." << objName << " = TQActionGroup(" << parent << ",b\"" << objName << "\")" << endl;
 	else
 	    continue;
 	bool subActionsDone = FALSE;
